==> odoo_18.0.20251026.zip: odoo-18.0.post20251026/odoo/addons/website_slides/tests/test_embed_detection.py <==
# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from odoo.addons.website_slides.tests import common
from odoo.tests import HttpCase


class TestEmbedDetection(HttpCase, common.SlidesCase):

    @classmethod
    def setUpClass(cls):
        super(TestEmbedDetection, cls).setUpClass()

        cls.website = cls.env['website'].create({
            'name': 'Test Website',
            'domain': 'https://testwebsite.com'
        })

        cls.channel.website_id = cls.website.id

    def test_embed_external_no_referer(self):
        """ When hitting the external URL without a referer header, the global embed record is
        incremented. """
        self.url_open(f'/slides/embed_external/{self.slide.id}')
        embed_views = self.env['slide.embed'].search([('slide_id', '=', self.slide.id)])
        self.assertEqual(len(embed_views), 1)
        self.assertEqual(embed_views.website_name, 'Unknown Website')

    def test_embed_external_referer(self):
        """ When hitting the external URL with a referer header, the embed record is incremented
        based on the referer URL. """

        self.assertFalse(bool(self.env['slide.embed'].search([
            ('slide_id', '=', self.slide.id)
        ])))

        self.url_open(
            f'/slides/embed_external/{self.slide.id}',
            headers={'Referer': 'https://someexternalwebsite.com'}
        )

        embed_views = self.env['slide.embed'].search([('slide_id', '=', self.slide.id)])
        self.assertEqual(len(embed_views), 1)
        self.assertEqual(embed_views.count_views, 1)
        self.assertEqual(embed_views.website_name, 'https://someexternalwebsite.com')

    def test_embed_not_external(self):
        """ When hitting the non-external URL, we should not add a slide_embed record. """
        self.url_open(f'/slides/embed/{self.slide.id}')
        self.assertFalse(bool(self.env['slide.embed'].search([
            ('slide_id', '=', self.slide.id)
        ])))

    def test_embed_category_slide(self):
        self.slide.channel_id.website_id = False
        res = self.url_open(f'/slides/embed/{self.category.id}')
        res.raise_for_status()
        self.assertFalse(bool(self.env['slide.embed'].search([
            ('slide_id', '=', self.category.id)
        ])))

    def test_embed_if_no_website_id(self):
        self.slide.channel_id.website_id = False
        res = self.url_open(f'/slides/embed/{self.slide.id}')
        res.raise_for_status()
        self.assertFalse(bool(self.env['slide.embed'].search([
            ('slide_id', '=', self.slide.id)
        ])))

==> odoo_19.2a1.20260107.zip: odoo-19.2a1.post20260107/odoo/addons/website_slides/tests/test_embed_detection.py <==
# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from odoo.addons.website_slides.tests import common
from odoo.tests import tagged, HttpCase


@tagged('at_install', '-post_install')  # LEGACY at_install
class TestEmbedDetection(HttpCase, common.SlidesCase):

    @classmethod
    def setUpClass(cls):
        super(TestEmbedDetection, cls).setUpClass()

        cls.website = cls.env['website'].create({
            'name': 'Test Website',
            'domain': 'https://testwebsite.com'
        })

        cls.channel.website_id = cls.website.id

    def test_embed_external_no_referer(self):
        """ When hitting the external URL without a referer header, the global embed record is
        incremented. """
        self.url_open(f'/slides/embed_external/{self.slide.id}')
        embed_views = self.env['slide.embed'].search([('slide_id', '=', self.slide.id)])
        self.assertEqual(len(embed_views), 1)
        self.assertEqual(embed_views.website_name, 'Unknown Website')

    def test_embed_external_referer(self):
        """ When hitting the external URL with a referer header, the embed record is incremented
        based on the referer URL. """

        self.assertFalse(bool(self.env['slide.embed'].search([
            ('slide_id', '=', self.slide.id)
        ])))

        self.url_open(
            f'/slides/embed_external/{self.slide.id}',
            headers={'Referer': 'https://someexternalwebsite.com'}
        )

        embed_views = self.env['slide.embed'].search([('slide_id', '=', self.slide.id)])
        self.assertEqual(len(embed_views), 1)
        self.assertEqual(embed_views.count_views, 1)
        self.assertEqual(embed_views.website_name, 'https://someexternalwebsite.com')

    def test_embed_not_external(self):
        """ When hitting the non-external URL, we should not add a slide_embed record. """
        self.url_open(f'/slides/embed/{self.slide.id}')
        self.assertFalse(bool(self.env['slide.embed'].search([
            ('slide_id', '=', self.slide.id)
        ])))

    def test_embed_category_slide(self):
        self.slide.channel_id.website_id = False
        res = self.url_open(f'/slides/embed/{self.category.id}')
        res.raise_for_status()
        self.assertFalse(bool(self.env['slide.embed'].search([
            ('slide_id', '=', self.category.id)
        ])))

    def test_embed_if_no_website_id(self):
        self.slide.channel_id.website_id = False
        res = self.url_open(f'/slides/embed/{self.slide.id}')
        res.raise_for_status()
        self.assertFalse(bool(self.env['slide.embed'].search([
            ('slide_id', '=', self.slide.id)
        ])))
